/***************************************************************************
 *   Copyright (C) 2004-2005 by Jürgen Kofler                                   *
 *   kaffeine@gmx.net                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
 ***************************************************************************/

 /*
  * Last modified: $Date: 2005/09/03 09:36:40 $ by $Author: juergenk $
  */

#ifndef MRL_H
#define MRL_H

#include <qdatetime.h>

/**
"Media Resource Locator"

 Holds url and media meta info.

@author Jürgen Kofler
*/

#include <kurl.h>
#include "kaffeine_export.h"

class QString;
class QStringList;

class KAFFEINE_EXPORT MRL
{
public:
   MRL();
   /* don't use this constructor to prevent encoding problems */
   MRL(const KURL& url, const QString& title = QString::null, const QTime& length = QTime(), const QString& mime = QString::null,
       const QString& artist = QString::null, const QString& album = QString::null, const QString& track = QString::null,
       const QString& year = QString::null, const QString& genre = QString::null, const QString& comment = QString::null,
       const QStringList& subtitleFiles = QStringList(), int currentSubtitle = -1);
   MRL(const QString& url, const QString& title = QString::null, const QTime& length = QTime(), const QString& mime = QString::null,
       const QString& artist = QString::null, const QString& album = QString::null, const QString& track = QString::null,
       const QString& year = QString::null, const QString& genre = QString::null, const QString& comment = QString::null,
       const QStringList& subtitleFiles = QStringList(), int currentSubtitle = -1);
   virtual ~MRL();

   virtual void reset();
   virtual bool isEmpty() const;

   virtual QString& url();
   virtual const QString& url() const;
   virtual KURL& kurl();
   virtual const KURL& kurl() const;
   virtual QString& title();
   virtual const QString& title() const;
   virtual QString& artist();
   virtual const QString& artist() const;
   virtual QString& album();
   virtual const QString& album() const;
   virtual QString& track();
   virtual const QString& track() const;
   virtual QString& year();
   virtual const QString& year() const;
   virtual QString& genre();
   virtual const QString& genre() const;
   virtual QString& comment();
   virtual const QString& comment() const;
   virtual QString& mime();
   virtual const QString& mime() const;
   virtual QTime& length();
   virtual const QTime& length() const;
   virtual QStringList& subtitleFiles();
   virtual const QStringList& subtitleFiles() const;
   virtual int currentSubtitle() const;

   virtual void setURL(const QString& url);
   virtual void setTitle(const QString& title);
   virtual void setArtist(const QString& artist);
   virtual void setAlbum(const QString& album);
   virtual void setTrack(const QString& track);
   virtual void setYear(const QString& year);
   virtual void setGenre(const QString& genre);
   virtual void setComment(const QString& comment);
   virtual void setMime(const QString& mime);
   virtual void setLength(const QTime& length);
   virtual void setSubtitleFiles(const QStringList& urls);
   virtual void addSubtitleFile(const QString& url);
   virtual void setCurrentSubtitle(int sub);

   class List : public QValueList<MRL>
   {
     public:
       List() {}
       List(const QString&);
     /*  List(const KURL&); */
       List(const QStringList&);
     /*  List(const KURL::List&); */
       QStringList toStringList() const;
       virtual ~List() {}
   };
private:
   QString m_url;
   KURL m_kurl;
   QString m_title;
   QString m_artist;
   QString m_album;
   QString m_track;
   QString m_year;
   QString m_genre;
   QString m_comment;
   QString m_mime;
   QTime m_length;
   QStringList m_subtitleFiles;
   int m_currentSubtitle; /* -1 -> off */
};

#endif
